# MIT License
#
# Copyright (c) 2020 David Krasnitsky
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

from . import rskeyring

__doc__ = rskeyring.__doc__


def get_password(service: str, username: str) -> str:
    """
    A function to get a stored password (secret item) from a specified service name & username (key).

    Raises "OSError" exception if item does not exists or otherwise cannot be retrieved.

    :param service: A unique service name
    :param username: A key name
    :return: Password (secret item)
    """
    return rskeyring.get_password(service, username)


def set_password(service: str, username: str, password: str) -> None:
    """
    A function that stores or updates a password (secret item) by a specified service name & username (key).

    Raises "OSError" exception if unable to set or update the password (secret item).

    :param service: A unique service name
    :param username: A key name
    :param password: A secret item
    :return: None
    """
    return rskeyring.set_password(service, username, password)


def delete_password(service: str, username: str) -> None:
    """
    A function to delete a stored password (secret item), specified by a service name & username (key).

    Raises "OSError" exception if item does not exists or otherwise unable to comply.

    :param service: A unique service name
    :param username: A key name
    :return: None
    """
    return rskeyring.delete_password(service, username)




import unittest
from uuid import uuid4

import rskeyring


def generate_password():
    return str(uuid4())


class RSKeyringTests(unittest.TestCase):

    service_name = "rskeyring_unit_test_service_name"
    username = "rskeyring_unit_test_username"

    def test_set_password(self):

        rskeyring.set_password(
            service=RSKeyringTests.service_name,
            username=RSKeyringTests.username,
            password=generate_password()
        )

    def test_update_password(self):

        first_password = generate_password()

        rskeyring.set_password(
            service=RSKeyringTests.service_name,
            username=RSKeyringTests.username,
            password=first_password
        )

        stored_password = rskeyring.get_password(
            service=RSKeyringTests.service_name,
            username=RSKeyringTests.username
        )

        self.assertEqual(first_password, stored_password)

        second_password = generate_password()

        rskeyring.set_password(
            service=RSKeyringTests.service_name,
            username=RSKeyringTests.username,
            password=second_password
        )

        stored_password = rskeyring.get_password(
            service=RSKeyringTests.service_name,
            username=RSKeyringTests.username
        )

        self.assertEqual(second_password, stored_password)

    def test_get_password(self):

        generated_password = generate_password()

        rskeyring.set_password(
            service=RSKeyringTests.service_name,
            username=RSKeyringTests.username,
            password=generated_password
        )

        stored_password = rskeyring.get_password(
            service=RSKeyringTests.service_name,
            username=RSKeyringTests.username
        )

        self.assertEqual(stored_password, generated_password)

    def test_delete_password(self):

        generated_password = generate_password()

        rskeyring.set_password(
            service=RSKeyringTests.service_name,
            username=RSKeyringTests.username,
            password=generated_password
        )

        stored_password = rskeyring.get_password(
            service=RSKeyringTests.service_name,
            username=RSKeyringTests.username
        )

        self.assertEqual(stored_password, generated_password)

        rskeyring.delete_password(
            service=RSKeyringTests.service_name,
            username=RSKeyringTests.username
        )

        with self.assertRaises(OSError):

            rskeyring.get_password(
                service=RSKeyringTests.service_name,
                username=RSKeyringTests.username
            )

    def test_exceptions(self):

        random_user_name = 'rskeyring_unittest_' + generate_password()

        with self.assertRaises(OSError):
            rskeyring.get_password(
                service=RSKeyringTests.service_name,
                username=random_user_name
            )

        with self.assertRaises(OSError):
            rskeyring.delete_password(
                service=RSKeyringTests.service_name,
                username=random_user_name
            )


if __name__ == '__main__':
    unittest.main()



from setuptools import setup
from setuptools import find_packages
from setuptools_rust import Binding
from setuptools_rust import RustExtension

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name="rskeyring",
    version="0.1.2.2",
    author="David Krasnitsky",
    author_email="dikaveman@gmail.com",
    description="A C-level keyring module bind from the Rust programming language (crates.io)",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/DK26/pyrust-keyring",
    rust_extensions=[RustExtension("rskeyring.rskeyring", binding=Binding.RustCPython)],
    packages=["rskeyring"] + find_packages(),
    include_package_data=True,
    classifiers=[
        "Programming Language :: Python :: 3",
        "Programming Language :: Rust",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent"
    ],
    python_requires='>=3.8',
    zip_safe=False
)
